# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import bombbomb
from bombbomb.rest import ApiException
from bombbomb.apis.teams_api import TeamsApi


class TestTeamsApi(unittest.TestCase):
    """ TeamsApi unit test stubs """

    def setUp(self):
        self.api = bombbomb.apis.teams_api.TeamsApi()

    def tearDown(self):
        pass

    def test_cancel_jericho_send(self):
        """
        Test case for cancel_jericho_send

        Cancel a Jericho Send
        """
        pass

    def test_get_client_group_assets(self):
        """
        Test case for get_client_group_assets

        Lists team assets
        """
        pass

    def test_get_jericho_sends(self):
        """
        Test case for get_jericho_sends

        List Jericho Sends
        """
        pass

    def test_get_jericho_stats(self):
        """
        Test case for get_jericho_stats

        Gets Jericho performance statistics
        """
        pass

    def test_queue_jericho_send(self):
        """
        Test case for queue_jericho_send

        Creates a Jericho send.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class WebhooksApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def add_web_hook(self, hook_url, **kwargs):
        """
        Add Webhook
        Idempotently adds a Webhook url

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_web_hook(hook_url, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str hook_url: The Url of your listener (required)
        :return: BBWebHook
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_web_hook_with_http_info(hook_url, **kwargs)
        else:
            (data) = self.add_web_hook_with_http_info(hook_url, **kwargs)
            return data

    def add_web_hook_with_http_info(self, hook_url, **kwargs):
        """
        Add Webhook
        Idempotently adds a Webhook url

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_web_hook_with_http_info(hook_url, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str hook_url: The Url of your listener (required)
        :return: BBWebHook
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['hook_url']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_web_hook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'hook_url' is set
        if ('hook_url' not in params) or (params['hook_url'] is None):
            raise ValueError("Missing the required parameter `hook_url` when calling `add_web_hook`")

        resource_path = '/webhook'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'hook_url' in params:
            form_params.append(('hookUrl', params['hook_url']))

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='BBWebHook',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def delete_web_hook(self, hook_id, **kwargs):
        """
        Deletes Webhook
        Deletes a Webhook

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_web_hook(hook_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str hook_id: The id of the webhook to delete (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_web_hook_with_http_info(hook_id, **kwargs)
        else:
            (data) = self.delete_web_hook_with_http_info(hook_id, **kwargs)
            return data

    def delete_web_hook_with_http_info(self, hook_id, **kwargs):
        """
        Deletes Webhook
        Deletes a Webhook

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_web_hook_with_http_info(hook_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str hook_id: The id of the webhook to delete (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['hook_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_web_hook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'hook_id' is set
        if ('hook_id' not in params) or (params['hook_id'] is None):
            raise ValueError("Missing the required parameter `hook_id` when calling `delete_web_hook`")

        resource_path = '/webhook/{hookId}'.replace('{format}', 'json')
        path_params = {}
        if 'hook_id' in params:
            path_params['hookId'] = params['hook_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='str',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_web_hooks(self, **kwargs):
        """
        Lists Webhooks
        Lists all registered Webhooks

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_web_hooks(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[BBWebHook]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_web_hooks_with_http_info(**kwargs)
        else:
            (data) = self.get_web_hooks_with_http_info(**kwargs)
            return data

    def get_web_hooks_with_http_info(self, **kwargs):
        """
        Lists Webhooks
        Lists all registered Webhooks

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_web_hooks_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[BBWebHook]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_web_hooks" % key
                )
            params[key] = val
        del params['kwargs']

        resource_path = '/webhook/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[BBWebHook]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def send_webhook_example(self, **kwargs):
        """
        Sends test Webhook
        Triggers a test webhook to be sent to your endpoints.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.send_webhook_example(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.send_webhook_example_with_http_info(**kwargs)
        else:
            (data) = self.send_webhook_example_with_http_info(**kwargs)
            return data

    def send_webhook_example_with_http_info(self, **kwargs):
        """
        Sends test Webhook
        Triggers a test webhook to be sent to your endpoints.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.send_webhook_example_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_webhook_example" % key
                )
            params[key] = val
        del params['kwargs']

        resource_path = '/webhook/test'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import bombbomb
from bombbomb.rest import ApiException
from bombbomb.apis.prompts_api import PromptsApi


class TestPromptsApi(unittest.TestCase):
    """ PromptsApi unit test stubs """

    def setUp(self):
        self.api = bombbomb.apis.prompts_api.PromptsApi()

    def tearDown(self):
        pass

    def test_create_video_email_prompt(self):
        """
        Test case for create_video_email_prompt

        Prompts user to send a video
        """
        pass

    def test_get_video_email_prompt(self):
        """
        Test case for get_video_email_prompt

        Gets a prompt
        """
        pass

    def test_respond_to_video_email_prompt(self):
        """
        Test case for respond_to_video_email_prompt

        Respond to a prompt
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import bombbomb
from bombbomb.rest import ApiException
from bombbomb.models.jericho_configuration import JerichoConfiguration


class TestJerichoConfiguration(unittest.TestCase):
    """ JerichoConfiguration unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testJerichoConfiguration(self):
        """
        Test JerichoConfiguration
        """
        model = bombbomb.models.jericho_configuration.JerichoConfiguration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import bombbomb
from bombbomb.rest import ApiException
from bombbomb.apis.webhooks_api import WebhooksApi


class TestWebhooksApi(unittest.TestCase):
    """ WebhooksApi unit test stubs """

    def setUp(self):
        self.api = bombbomb.apis.webhooks_api.WebhooksApi()

    def tearDown(self):
        pass

    def test_add_web_hook(self):
        """
        Test case for add_web_hook

        Add Webhook
        """
        pass

    def test_delete_web_hook(self):
        """
        Test case for delete_web_hook

        Deletes Webhook
        """
        pass

    def test_get_web_hooks(self):
        """
        Test case for get_web_hooks

        Lists Webhooks
        """
        pass

    def test_send_webhook_example(self):
        """
        Test case for send_webhook_example

        Sends test Webhook
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

# import models into model package
from .bb_web_hook import BBWebHook
from .inline_response_200 import InlineResponse200
from .inline_response_200_items import InlineResponse200Items
from .jericho_configuration import JerichoConfiguration
from .jericho_performance import JerichoPerformance
from .o_auth_client import OAuthClient
from .string import String
from .video_email_prompt import VideoEmailPrompt



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class JerichoPerformance(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, sent=None, unique_views=None, unique_landing_page_views=None, landing_page_views=None, delivered=None, bounce=None, open=None, click=None, video_play=None, abuse_complaints=None, contacts=None):
        """
        JerichoPerformance - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'sent': 'int',
            'unique_views': 'int',
            'unique_landing_page_views': 'int',
            'landing_page_views': 'int',
            'delivered': 'int',
            'bounce': 'int',
            'open': 'int',
            'click': 'int',
            'video_play': 'int',
            'abuse_complaints': 'int',
            'contacts': 'int'
        }

        self.attribute_map = {
            'sent': 'sent',
            'unique_views': 'uniqueViews',
            'unique_landing_page_views': 'uniqueLandingPageViews',
            'landing_page_views': 'landingPageViews',
            'delivered': 'delivered',
            'bounce': 'bounce',
            'open': 'open',
            'click': 'click',
            'video_play': 'videoPlay',
            'abuse_complaints': 'abuseComplaints',
            'contacts': 'contacts'
        }

        self._sent = sent
        self._unique_views = unique_views
        self._unique_landing_page_views = unique_landing_page_views
        self._landing_page_views = landing_page_views
        self._delivered = delivered
        self._bounce = bounce
        self._open = open
        self._click = click
        self._video_play = video_play
        self._abuse_complaints = abuse_complaints
        self._contacts = contacts

    @property
    def sent(self):
        """
        Gets the sent of this JerichoPerformance.
        The number of emails sent

        :return: The sent of this JerichoPerformance.
        :rtype: int
        """
        return self._sent

    @sent.setter
    def sent(self, sent):
        """
        Sets the sent of this JerichoPerformance.
        The number of emails sent

        :param sent: The sent of this JerichoPerformance.
        :type: int
        """

        self._sent = sent

    @property
    def unique_views(self):
        """
        Gets the unique_views of this JerichoPerformance.
        The unique number of people that viewed the email

        :return: The unique_views of this JerichoPerformance.
        :rtype: int
        """
        return self._unique_views

    @unique_views.setter
    def unique_views(self, unique_views):
        """
        Sets the unique_views of this JerichoPerformance.
        The unique number of people that viewed the email

        :param unique_views: The unique_views of this JerichoPerformance.
        :type: int
        """

        self._unique_views = unique_views

    @property
    def unique_landing_page_views(self):
        """
        Gets the unique_landing_page_views of this JerichoPerformance.
        The unique number of people that visited the landing page

        :return: The unique_landing_page_views of this JerichoPerformance.
        :rtype: int
        """
        return self._unique_landing_page_views

    @unique_landing_page_views.setter
    def unique_landing_page_views(self, unique_landing_page_views):
        """
        Sets the unique_landing_page_views of this JerichoPerformance.
        The unique number of people that visited the landing page

        :param unique_landing_page_views: The unique_landing_page_views of this JerichoPerformance.
        :type: int
        """

        self._unique_landing_page_views = unique_landing_page_views

    @property
    def landing_page_views(self):
        """
        Gets the landing_page_views of this JerichoPerformance.
        The total number of people that visisted the landing page

        :return: The landing_page_views of this JerichoPerformance.
        :rtype: int
        """
        return self._landing_page_views

    @landing_page_views.setter
    def landing_page_views(self, landing_page_views):
        """
        Sets the landing_page_views of this JerichoPerformance.
        The total number of people that visisted the landing page

        :param landing_page_views: The landing_page_views of this JerichoPerformance.
        :type: int
        """

        self._landing_page_views = landing_page_views

    @property
    def delivered(self):
        """
        Gets the delivered of this JerichoPerformance.
        The number of emails delivered, likely less than sent due to bounces, and other common delivery issues

        :return: The delivered of this JerichoPerformance.
        :rtype: int
        """
        return self._delivered

    @delivered.setter
    def delivered(self, delivered):
        """
        Sets the delivered of this JerichoPerformance.
        The number of emails delivered, likely less than sent due to bounces, and other common delivery issues

        :param delivered: The delivered of this JerichoPerformance.
        :type: int
        """

        self._delivered = delivered

    @property
    def bounce(self):
        """
        Gets the bounce of this JerichoPerformance.
        The number of emails that bounced as undeliverable

        :return: The bounce of this JerichoPerformance.
        :rtype: int
        """
        return self._bounce

    @bounce.setter
    def bounce(self, bounce):
        """
        Sets the bounce of this JerichoPerformance.
        The number of emails that bounced as undeliverable

        :param bounce: The bounce of this JerichoPerformance.
        :type: int
        """

        self._bounce = bounce

    @property
    def open(self):
        """
        Gets the open of this JerichoPerformance.
        The total number of times the emails were viewed

        :return: The open of this JerichoPerformance.
        :rtype: int
        """
        return self._open

    @open.setter
    def open(self, open):
        """
        Sets the open of this JerichoPerformance.
        The total number of times the emails were viewed

        :param open: The open of this JerichoPerformance.
        :type: int
        """

        self._open = open

    @property
    def click(self):
        """
        Gets the click of this JerichoPerformance.
        The total number of times links in the emails were clicked

        :return: The click of this JerichoPerformance.
        :rtype: int
        """
        return self._click

    @click.setter
    def click(self, click):
        """
        Sets the click of this JerichoPerformance.
        The total number of times links in the emails were clicked

        :param click: The click of this JerichoPerformance.
        :type: int
        """

        self._click = click

    @property
    def video_play(self):
        """
        Gets the video_play of this JerichoPerformance.
        The total number of times videos in the emails were played

        :return: The video_play of this JerichoPerformance.
        :rtype: int
        """
        return self._video_play

    @video_play.setter
    def video_play(self, video_play):
        """
        Sets the video_play of this JerichoPerformance.
        The total number of times videos in the emails were played

        :param video_play: The video_play of this JerichoPerformance.
        :type: int
        """

        self._video_play = video_play

    @property
    def abuse_complaints(self):
        """
        Gets the abuse_complaints of this JerichoPerformance.
        The number of recipients that marked the message as abusive

        :return: The abuse_complaints of this JerichoPerformance.
        :rtype: int
        """
        return self._abuse_complaints

    @abuse_complaints.setter
    def abuse_complaints(self, abuse_complaints):
        """
        Sets the abuse_complaints of this JerichoPerformance.
        The number of recipients that marked the message as abusive

        :param abuse_complaints: The abuse_complaints of this JerichoPerformance.
        :type: int
        """

        self._abuse_complaints = abuse_complaints

    @property
    def contacts(self):
        """
        Gets the contacts of this JerichoPerformance.
        The total number of contacts submitted to be sent, may be more than was sent to

        :return: The contacts of this JerichoPerformance.
        :rtype: int
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """
        Sets the contacts of this JerichoPerformance.
        The total number of contacts submitted to be sent, may be more than was sent to

        :param contacts: The contacts of this JerichoPerformance.
        :type: int
        """

        self._contacts = contacts

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import absolute_import

# import apis into api package
from .prompts_api import PromptsApi
from .teams_api import TeamsApi
from .utilities_api import UtilitiesApi
from .webhooks_api import WebhooksApi



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class JerichoConfiguration(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, send_date=None, is_prompt=None, email_id=None, prompt_subject=None, prompt_body=None, email_subject=None, email_body=None, send_without_video=None):
        """
        JerichoConfiguration - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'client_group_id': 'str',
            'send_date': 'datetime',
            'is_prompt': 'bool',
            'email_id': 'str',
            'prompt_subject': 'str',
            'prompt_body': 'str',
            'email_subject': 'str',
            'email_body': 'str',
            'send_without_video': 'bool',
            'status': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'client_group_id': 'clientGroupId',
            'send_date': 'sendDate',
            'is_prompt': 'isPrompt',
            'email_id': 'emailId',
            'prompt_subject': 'promptSubject',
            'prompt_body': 'promptBody',
            'email_subject': 'emailSubject',
            'email_body': 'emailBody',
            'send_without_video': 'sendWithoutVideo',
            'status': 'status'
        }

        self._id = None
        self._client_group_id = None
        self._status = None
        self._send_date = send_date
        self._is_prompt = is_prompt
        self._email_id = email_id
        self._prompt_subject = prompt_subject
        self._prompt_body = prompt_body
        self._email_subject = email_subject
        self._email_body = email_body
        self._send_without_video = send_without_video

    @property
    def id(self):
        """
        Gets the id of this JerichoConfiguration.


        :return: The id of this JerichoConfiguration.
        :rtype: str
        """
        return self._id

    @property
    def client_group_id(self):
        """
        Gets the client_group_id of this JerichoConfiguration.


        :return: The client_group_id of this JerichoConfiguration.
        :rtype: str
        """
        return self._client_group_id

    @property
    def send_date(self):
        """
        Gets the send_date of this JerichoConfiguration.
        When the email should be sent.

        :return: The send_date of this JerichoConfiguration.
        :rtype: datetime
        """
        return self._send_date

    @send_date.setter
    def send_date(self, send_date):
        """
        Sets the send_date of this JerichoConfiguration.
        When the email should be sent.

        :param send_date: The send_date of this JerichoConfiguration.
        :type: datetime
        """

        self._send_date = send_date

    @property
    def is_prompt(self):
        """
        Gets the is_prompt of this JerichoConfiguration.
        Determines whether this is a static or prompted send.

        :return: The is_prompt of this JerichoConfiguration.
        :rtype: bool
        """
        return self._is_prompt

    @is_prompt.setter
    def is_prompt(self, is_prompt):
        """
        Sets the is_prompt of this JerichoConfiguration.
        Determines whether this is a static or prompted send.

        :param is_prompt: The is_prompt of this JerichoConfiguration.
        :type: bool
        """

        self._is_prompt = is_prompt

    @property
    def email_id(self):
        """
        Gets the email_id of this JerichoConfiguration.
        Static send: The Email to send on behalf of the group members.

        :return: The email_id of this JerichoConfiguration.
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """
        Sets the email_id of this JerichoConfiguration.
        Static send: The Email to send on behalf of the group members.

        :param email_id: The email_id of this JerichoConfiguration.
        :type: str
        """

        self._email_id = email_id

    @property
    def prompt_subject(self):
        """
        Gets the prompt_subject of this JerichoConfiguration.
        Video Prompt: The subject line prompting the user to record a video.

        :return: The prompt_subject of this JerichoConfiguration.
        :rtype: str
        """
        return self._prompt_subject

    @prompt_subject.setter
    def prompt_subject(self, prompt_subject):
        """
        Sets the prompt_subject of this JerichoConfiguration.
        Video Prompt: The subject line prompting the user to record a video.

        :param prompt_subject: The prompt_subject of this JerichoConfiguration.
        :type: str
        """

        self._prompt_subject = prompt_subject

    @property
    def prompt_body(self):
        """
        Gets the prompt_body of this JerichoConfiguration.
        Video Prompt: The HTML body of the email prompting the user to record a video.

        :return: The prompt_body of this JerichoConfiguration.
        :rtype: str
        """
        return self._prompt_body

    @prompt_body.setter
    def prompt_body(self, prompt_body):
        """
        Sets the prompt_body of this JerichoConfiguration.
        Video Prompt: The HTML body of the email prompting the user to record a video.

        :param prompt_body: The prompt_body of this JerichoConfiguration.
        :type: str
        """

        self._prompt_body = prompt_body

    @property
    def email_subject(self):
        """
        Gets the email_subject of this JerichoConfiguration.
        Video Prompt: The subject line of the final sent email

        :return: The email_subject of this JerichoConfiguration.
        :rtype: str
        """
        return self._email_subject

    @email_subject.setter
    def email_subject(self, email_subject):
        """
        Sets the email_subject of this JerichoConfiguration.
        Video Prompt: The subject line of the final sent email

        :param email_subject: The email_subject of this JerichoConfiguration.
        :type: str
        """

        self._email_subject = email_subject

    @property
    def email_body(self):
        """
        Gets the email_body of this JerichoConfiguration.
        Video Prompt: The HTML body of the final sent email.

        :return: The email_body of this JerichoConfiguration.
        :rtype: str
        """
        return self._email_body

    @email_body.setter
    def email_body(self, email_body):
        """
        Sets the email_body of this JerichoConfiguration.
        Video Prompt: The HTML body of the final sent email.

        :param email_body: The email_body of this JerichoConfiguration.
        :type: str
        """

        self._email_body = email_body

    @property
    def send_without_video(self):
        """
        Gets the send_without_video of this JerichoConfiguration.
        Video Prompt: Whether to send the final email if no video was recorded.

        :return: The send_without_video of this JerichoConfiguration.
        :rtype: bool
        """
        return self._send_without_video

    @send_without_video.setter
    def send_without_video(self, send_without_video):
        """
        Sets the send_without_video of this JerichoConfiguration.
        Video Prompt: Whether to send the final email if no video was recorded.

        :param send_without_video: The send_without_video of this JerichoConfiguration.
        :type: bool
        """

        self._send_without_video = send_without_video

    @property
    def status(self):
        """
        Gets the status of this JerichoConfiguration.
        The state of the send.

        :return: The status of this JerichoConfiguration.
        :rtype: str
        """
        return self._status

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class PromptsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_video_email_prompt(self, prompt, **kwargs):
        """
        Prompts user to send a video
        Sends the account holder an email prompting them to add a video to a scheduled outgoing message. Recipients, content and timing is all preset for the user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_video_email_prompt(prompt, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VideoEmailPrompt prompt: The Video Email Prompt to be created (required)
        :return: VideoEmailPrompt
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_video_email_prompt_with_http_info(prompt, **kwargs)
        else:
            (data) = self.create_video_email_prompt_with_http_info(prompt, **kwargs)
            return data

    def create_video_email_prompt_with_http_info(self, prompt, **kwargs):
        """
        Prompts user to send a video
        Sends the account holder an email prompting them to add a video to a scheduled outgoing message. Recipients, content and timing is all preset for the user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_video_email_prompt_with_http_info(prompt, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VideoEmailPrompt prompt: The Video Email Prompt to be created (required)
        :return: VideoEmailPrompt
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['prompt']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_video_email_prompt" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'prompt' is set
        if ('prompt' not in params) or (params['prompt'] is None):
            raise ValueError("Missing the required parameter `prompt` when calling `create_video_email_prompt`")

        resource_path = '/prompt'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'prompt' in params:
            body_params = params['prompt']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VideoEmailPrompt',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_video_email_prompt(self, id, **kwargs):
        """
        Gets a prompt
        Gets a prompt

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_video_email_prompt(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Id of the prompt (required)
        :return: VideoEmailPrompt
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_video_email_prompt_with_http_info(id, **kwargs)
        else:
            (data) = self.get_video_email_prompt_with_http_info(id, **kwargs)
            return data

    def get_video_email_prompt_with_http_info(self, id, **kwargs):
        """
        Gets a prompt
        Gets a prompt

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_video_email_prompt_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Id of the prompt (required)
        :return: VideoEmailPrompt
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_video_email_prompt" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_video_email_prompt`")

        resource_path = '/prompt/{id}'.replace('{format}', 'json')
        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VideoEmailPrompt',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def respond_to_video_email_prompt(self, id, choice, **kwargs):
        """
        Respond to a prompt
        Respond to a prompt by either adding a video, sending without a video or cancelling the prompt.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.respond_to_video_email_prompt(id, choice, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The id of the prompt. (required)
        :param str choice: The users' selection. Can be: WithVideo, WithoutVideo, Cancel (required)
        :param str video_id: The id of the video.
        :return: VideoEmailPrompt
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.respond_to_video_email_prompt_with_http_info(id, choice, **kwargs)
        else:
            (data) = self.respond_to_video_email_prompt_with_http_info(id, choice, **kwargs)
            return data

    def respond_to_video_email_prompt_with_http_info(self, id, choice, **kwargs):
        """
        Respond to a prompt
        Respond to a prompt by either adding a video, sending without a video or cancelling the prompt.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.respond_to_video_email_prompt_with_http_info(id, choice, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The id of the prompt. (required)
        :param str choice: The users' selection. Can be: WithVideo, WithoutVideo, Cancel (required)
        :param str video_id: The id of the video.
        :return: VideoEmailPrompt
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'choice', 'video_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method respond_to_video_email_prompt" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `respond_to_video_email_prompt`")
        # verify the required parameter 'choice' is set
        if ('choice' not in params) or (params['choice'] is None):
            raise ValueError("Missing the required parameter `choice` when calling `respond_to_video_email_prompt`")

        resource_path = '/prompt/{id}/response'.replace('{format}', 'json')
        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'video_id' in params:
            form_params.append(('videoId', params['video_id']))
        if 'choice' in params:
            form_params.append(('choice', params['choice']))

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VideoEmailPrompt',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class TeamsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def cancel_jericho_send(self, jericho_id, **kwargs):
        """
        Cancel a Jericho Send
        Cancels a scheduled Jericho send from being sent.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.cancel_jericho_send(jericho_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str jericho_id: ID of the Jericho Job to cancel (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.cancel_jericho_send_with_http_info(jericho_id, **kwargs)
        else:
            (data) = self.cancel_jericho_send_with_http_info(jericho_id, **kwargs)
            return data

    def cancel_jericho_send_with_http_info(self, jericho_id, **kwargs):
        """
        Cancel a Jericho Send
        Cancels a scheduled Jericho send from being sent.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.cancel_jericho_send_with_http_info(jericho_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str jericho_id: ID of the Jericho Job to cancel (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['jericho_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_jericho_send" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'jericho_id' is set
        if ('jericho_id' not in params) or (params['jericho_id'] is None):
            raise ValueError("Missing the required parameter `jericho_id` when calling `cancel_jericho_send`")

        resource_path = '/team/{teamId}/jericho/{jerichoId}'.replace('{format}', 'json')
        path_params = {}
        if 'jericho_id' in params:
            path_params['jerichoId'] = params['jericho_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_client_group_assets(self, asset_type, **kwargs):
        """
        Lists team assets
        Returns a collection of assets

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_client_group_assets(asset_type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str asset_type: The type of assets. (required)
        :param str team_id: The team containing the assets.
        :param str auto_tag_name: The auto tag name containing the assets.
        :param str page_size: The number of items to retrieve in a single db query.
        :param str page: Zero-based index of the page of data to retrieve from the db.
        :param str search: Search words.
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_client_group_assets_with_http_info(asset_type, **kwargs)
        else:
            (data) = self.get_client_group_assets_with_http_info(asset_type, **kwargs)
            return data

    def get_client_group_assets_with_http_info(self, asset_type, **kwargs):
        """
        Lists team assets
        Returns a collection of assets

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_client_group_assets_with_http_info(asset_type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str asset_type: The type of assets. (required)
        :param str team_id: The team containing the assets.
        :param str auto_tag_name: The auto tag name containing the assets.
        :param str page_size: The number of items to retrieve in a single db query.
        :param str page: Zero-based index of the page of data to retrieve from the db.
        :param str search: Search words.
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_type', 'team_id', 'auto_tag_name', 'page_size', 'page', 'search']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_client_group_assets" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_type' is set
        if ('asset_type' not in params) or (params['asset_type'] is None):
            raise ValueError("Missing the required parameter `asset_type` when calling `get_client_group_assets`")

        resource_path = '/team/assets/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'asset_type' in params:
            query_params['assetType'] = params['asset_type']
        if 'team_id' in params:
            query_params['teamId'] = params['team_id']
        if 'auto_tag_name' in params:
            query_params['autoTagName'] = params['auto_tag_name']
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page' in params:
            query_params['page'] = params['page']
        if 'search' in params:
            query_params['search'] = params['search']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='InlineResponse200',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_jericho_sends(self, team_id, **kwargs):
        """
        List Jericho Sends
        Lists Jericho sends, both pending and sent.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_jericho_sends(team_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str team_id: The team whose Jericho sends you wish to see. (required)
        :return: list[JerichoConfiguration]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_jericho_sends_with_http_info(team_id, **kwargs)
        else:
            (data) = self.get_jericho_sends_with_http_info(team_id, **kwargs)
            return data

    def get_jericho_sends_with_http_info(self, team_id, **kwargs):
        """
        List Jericho Sends
        Lists Jericho sends, both pending and sent.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_jericho_sends_with_http_info(team_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str team_id: The team whose Jericho sends you wish to see. (required)
        :return: list[JerichoConfiguration]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_jericho_sends" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_id' is set
        if ('team_id' not in params) or (params['team_id'] is None):
            raise ValueError("Missing the required parameter `team_id` when calling `get_jericho_sends`")

        resource_path = '/team/{teamId}/jericho'.replace('{format}', 'json')
        path_params = {}
        if 'team_id' in params:
            path_params['teamId'] = params['team_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[JerichoConfiguration]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_jericho_stats(self, jericho_id, team_id, **kwargs):
        """
        Gets Jericho performance statistics
        Returns an aggregate view of the performance of a Jericho send

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_jericho_stats(jericho_id, team_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str jericho_id: ID of the Jericho job (required)
        :param str team_id: ID of team through which Jericho was sent (required)
        :return: JerichoPerformance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_jericho_stats_with_http_info(jericho_id, team_id, **kwargs)
        else:
            (data) = self.get_jericho_stats_with_http_info(jericho_id, team_id, **kwargs)
            return data

    def get_jericho_stats_with_http_info(self, jericho_id, team_id, **kwargs):
        """
        Gets Jericho performance statistics
        Returns an aggregate view of the performance of a Jericho send

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_jericho_stats_with_http_info(jericho_id, team_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str jericho_id: ID of the Jericho job (required)
        :param str team_id: ID of team through which Jericho was sent (required)
        :return: JerichoPerformance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['jericho_id', 'team_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_jericho_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'jericho_id' is set
        if ('jericho_id' not in params) or (params['jericho_id'] is None):
            raise ValueError("Missing the required parameter `jericho_id` when calling `get_jericho_stats`")
        # verify the required parameter 'team_id' is set
        if ('team_id' not in params) or (params['team_id'] is None):
            raise ValueError("Missing the required parameter `team_id` when calling `get_jericho_stats`")

        resource_path = '/team/{teamId}/jericho/{jerichoId}/performance'.replace('{format}', 'json')
        path_params = {}
        if 'jericho_id' in params:
            path_params['jerichoId'] = params['jericho_id']
        if 'team_id' in params:
            path_params['teamId'] = params['team_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='JerichoPerformance',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def queue_jericho_send(self, config, team_id, **kwargs):
        """
        Creates a Jericho send.
        Sends email content on behalf of members of a client group. There are two forms this send can take:         Static Email, and Video Prompt. Static emails require only an emailId.         Video Prompts build emails dynamically and require most of the other fields.         You must be an administrator of a Team Account to use this method.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.queue_jericho_send(config, team_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param JerichoConfiguration config: JSON representing a Jericho configuration (required)
        :param str team_id: The ID of the team. (required)
        :return: JerichoConfiguration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.queue_jericho_send_with_http_info(config, team_id, **kwargs)
        else:
            (data) = self.queue_jericho_send_with_http_info(config, team_id, **kwargs)
            return data

    def queue_jericho_send_with_http_info(self, config, team_id, **kwargs):
        """
        Creates a Jericho send.
        Sends email content on behalf of members of a client group. There are two forms this send can take:         Static Email, and Video Prompt. Static emails require only an emailId.         Video Prompts build emails dynamically and require most of the other fields.         You must be an administrator of a Team Account to use this method.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.queue_jericho_send_with_http_info(config, team_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param JerichoConfiguration config: JSON representing a Jericho configuration (required)
        :param str team_id: The ID of the team. (required)
        :return: JerichoConfiguration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['config', 'team_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queue_jericho_send" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'config' is set
        if ('config' not in params) or (params['config'] is None):
            raise ValueError("Missing the required parameter `config` when calling `queue_jericho_send`")
        # verify the required parameter 'team_id' is set
        if ('team_id' not in params) or (params['team_id'] is None):
            raise ValueError("Missing the required parameter `team_id` when calling `queue_jericho_send`")

        resource_path = '/team/{teamId}/jericho'.replace('{format}', 'json')
        path_params = {}
        if 'team_id' in params:
            path_params['teamId'] = params['team_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'config' in params:
            body_params = params['config']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='JerichoConfiguration',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class UtilitiesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_o_auth_client(self, name, redirect_uri, **kwargs):
        """
        Create an OAuth Client
        Creates an OAuth Client managed by the user

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_o_auth_client(name, redirect_uri, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: The name of the OAuth client. e.g. MyCrm DEV, or MyCrm PROD (required)
        :param str redirect_uri: The URI to direct the client to after logging in. (required)
        :return: OAuthClient
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_o_auth_client_with_http_info(name, redirect_uri, **kwargs)
        else:
            (data) = self.create_o_auth_client_with_http_info(name, redirect_uri, **kwargs)
            return data

    def create_o_auth_client_with_http_info(self, name, redirect_uri, **kwargs):
        """
        Create an OAuth Client
        Creates an OAuth Client managed by the user

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_o_auth_client_with_http_info(name, redirect_uri, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: The name of the OAuth client. e.g. MyCrm DEV, or MyCrm PROD (required)
        :param str redirect_uri: The URI to direct the client to after logging in. (required)
        :return: OAuthClient
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'redirect_uri']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_o_auth_client" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `create_o_auth_client`")
        # verify the required parameter 'redirect_uri' is set
        if ('redirect_uri' not in params) or (params['redirect_uri'] is None):
            raise ValueError("Missing the required parameter `redirect_uri` when calling `create_o_auth_client`")

        resource_path = '/oauthclient'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'name' in params:
            form_params.append(('name', params['name']))
        if 'redirect_uri' in params:
            form_params.append(('redirectUri', params['redirect_uri']))

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OAuthClient',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def delete_o_auth_client(self, id, **kwargs):
        """
        Delete an OAuth Client
        Deletes an OAuth Client managed by the user

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_o_auth_client(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The id of the OAuth Client (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_o_auth_client_with_http_info(id, **kwargs)
        else:
            (data) = self.delete_o_auth_client_with_http_info(id, **kwargs)
            return data

    def delete_o_auth_client_with_http_info(self, id, **kwargs):
        """
        Delete an OAuth Client
        Deletes an OAuth Client managed by the user

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_o_auth_client_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The id of the OAuth Client (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_o_auth_client" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_o_auth_client`")

        resource_path = '/oauthclient/{id}'.replace('{format}', 'json')
        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_o_auth_clients(self, **kwargs):
        """
        Lists OAuth Clients
        Enumerates OAuth Clients managed by the user

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_o_auth_clients(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[OAuthClient]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_o_auth_clients_with_http_info(**kwargs)
        else:
            (data) = self.get_o_auth_clients_with_http_info(**kwargs)
            return data

    def get_o_auth_clients_with_http_info(self, **kwargs):
        """
        Lists OAuth Clients
        Enumerates OAuth Clients managed by the user

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_o_auth_clients_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[OAuthClient]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_o_auth_clients" % key
                )
            params[key] = val
        del params['kwargs']

        resource_path = '/oauthclient'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['BBOAuth2']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[OAuthClient]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_spec(self, **kwargs):
        """
        Describes this api
        Describes methods available through the API.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_spec(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_spec_with_http_info(**kwargs)
        else:
            (data) = self.get_spec_with_http_info(**kwargs)
            return data

    def get_spec_with_http_info(self, **kwargs):
        """
        Describes this api
        Describes methods available through the API.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_spec_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_spec" % key
                )
            params[key] = val
        del params['kwargs']

        resource_path = '/spec'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class VideoEmailPrompt(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, template_id=None, email_subject_line=None, email_content=None, to_email_addresses=None, to_lists=None, jericho_id=None, prompt_subject=None, prompt_html=None, send_without_video=None, video_due_date=None, scheduled_send_date=None, do_not_apply_template=None):
        """
        VideoEmailPrompt - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'user_id': 'str',
            'template_id': 'str',
            'email_subject_line': 'str',
            'email_content': 'str',
            'to_email_addresses': 'list[str]',
            'to_lists': 'list[str]',
            'jericho_id': 'str',
            'prompt_subject': 'str',
            'prompt_html': 'str',
            'send_without_video': 'bool',
            'video_due_date': 'datetime',
            'scheduled_send_date': 'datetime',
            'video_id': 'str',
            'email_id': 'str',
            'job_id': 'str',
            'status': 'int',
            'do_not_apply_template': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'user_id': 'userId',
            'template_id': 'templateId',
            'email_subject_line': 'emailSubjectLine',
            'email_content': 'emailContent',
            'to_email_addresses': 'toEmailAddresses',
            'to_lists': 'toLists',
            'jericho_id': 'jerichoId',
            'prompt_subject': 'promptSubject',
            'prompt_html': 'promptHtml',
            'send_without_video': 'sendWithoutVideo',
            'video_due_date': 'videoDueDate',
            'scheduled_send_date': 'scheduledSendDate',
            'video_id': 'videoId',
            'email_id': 'emailId',
            'job_id': 'jobId',
            'status': 'status',
            'do_not_apply_template': 'doNotApplyTemplate'
        }

        self._id = None
        self._user_id = None
        self._video_id = None
        self._email_id = None
        self._job_id = None
        self._status = None
        self._template_id = template_id
        self._email_subject_line = email_subject_line
        self._email_content = email_content
        self._to_email_addresses = to_email_addresses
        self._to_lists = to_lists
        self._jericho_id = jericho_id
        self._prompt_subject = prompt_subject
        self._prompt_html = prompt_html
        self._send_without_video = send_without_video
        self._video_due_date = video_due_date
        self._scheduled_send_date = scheduled_send_date
        self._do_not_apply_template = do_not_apply_template

    @property
    def id(self):
        """
        Gets the id of this VideoEmailPrompt.
        The identifier of the prompt. Read Only.

        :return: The id of this VideoEmailPrompt.
        :rtype: str
        """
        return self._id

    @property
    def user_id(self):
        """
        Gets the user_id of this VideoEmailPrompt.
        The prompt's owner. Read Only.

        :return: The user_id of this VideoEmailPrompt.
        :rtype: str
        """
        return self._user_id

    @property
    def template_id(self):
        """
        Gets the template_id of this VideoEmailPrompt.
        Optional. The email template to be used in the sent email, if none supplied, the users' default will be applied.

        :return: The template_id of this VideoEmailPrompt.
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """
        Sets the template_id of this VideoEmailPrompt.
        Optional. The email template to be used in the sent email, if none supplied, the users' default will be applied.

        :param template_id: The template_id of this VideoEmailPrompt.
        :type: str
        """

        self._template_id = template_id

    @property
    def email_subject_line(self):
        """
        Gets the email_subject_line of this VideoEmailPrompt.
        The subject line of the final email

        :return: The email_subject_line of this VideoEmailPrompt.
        :rtype: str
        """
        return self._email_subject_line

    @email_subject_line.setter
    def email_subject_line(self, email_subject_line):
        """
        Sets the email_subject_line of this VideoEmailPrompt.
        The subject line of the final email

        :param email_subject_line: The email_subject_line of this VideoEmailPrompt.
        :type: str
        """

        self._email_subject_line = email_subject_line

    @property
    def email_content(self):
        """
        Gets the email_content of this VideoEmailPrompt.
        The HTML content of the final email

        :return: The email_content of this VideoEmailPrompt.
        :rtype: str
        """
        return self._email_content

    @email_content.setter
    def email_content(self, email_content):
        """
        Sets the email_content of this VideoEmailPrompt.
        The HTML content of the final email

        :param email_content: The email_content of this VideoEmailPrompt.
        :type: str
        """

        self._email_content = email_content

    @property
    def to_email_addresses(self):
        """
        Gets the to_email_addresses of this VideoEmailPrompt.
        Email addresses to send the final email to, can be mixed with listIds.

        :return: The to_email_addresses of this VideoEmailPrompt.
        :rtype: list[str]
        """
        return self._to_email_addresses

    @to_email_addresses.setter
    def to_email_addresses(self, to_email_addresses):
        """
        Sets the to_email_addresses of this VideoEmailPrompt.
        Email addresses to send the final email to, can be mixed with listIds.

        :param to_email_addresses: The to_email_addresses of this VideoEmailPrompt.
        :type: list[str]
        """

        self._to_email_addresses = to_email_addresses

    @property
    def to_lists(self):
        """
        Gets the to_lists of this VideoEmailPrompt.
        List Ids to send the final email to

        :return: The to_lists of this VideoEmailPrompt.
        :rtype: list[str]
        """
        return self._to_lists

    @to_lists.setter
    def to_lists(self, to_lists):
        """
        Sets the to_lists of this VideoEmailPrompt.
        List Ids to send the final email to

        :param to_lists: The to_lists of this VideoEmailPrompt.
        :type: list[str]
        """

        self._to_lists = to_lists

    @property
    def jericho_id(self):
        """
        Gets the jericho_id of this VideoEmailPrompt.
        If sent in a jericho context, this will have the jericho id

        :return: The jericho_id of this VideoEmailPrompt.
        :rtype: str
        """
        return self._jericho_id

    @jericho_id.setter
    def jericho_id(self, jericho_id):
        """
        Sets the jericho_id of this VideoEmailPrompt.
        If sent in a jericho context, this will have the jericho id

        :param jericho_id: The jericho_id of this VideoEmailPrompt.
        :type: str
        """

        self._jericho_id = jericho_id

    @property
    def prompt_subject(self):
        """
        Gets the prompt_subject of this VideoEmailPrompt.
        The prompt's subject line

        :return: The prompt_subject of this VideoEmailPrompt.
        :rtype: str
        """
        return self._prompt_subject

    @prompt_subject.setter
    def prompt_subject(self, prompt_subject):
        """
        Sets the prompt_subject of this VideoEmailPrompt.
        The prompt's subject line

        :param prompt_subject: The prompt_subject of this VideoEmailPrompt.
        :type: str
        """

        self._prompt_subject = prompt_subject

    @property
    def prompt_html(self):
        """
        Gets the prompt_html of this VideoEmailPrompt.
        The HTML body of the prompt

        :return: The prompt_html of this VideoEmailPrompt.
        :rtype: str
        """
        return self._prompt_html

    @prompt_html.setter
    def prompt_html(self, prompt_html):
        """
        Sets the prompt_html of this VideoEmailPrompt.
        The HTML body of the prompt

        :param prompt_html: The prompt_html of this VideoEmailPrompt.
        :type: str
        """

        self._prompt_html = prompt_html

    @property
    def send_without_video(self):
        """
        Gets the send_without_video of this VideoEmailPrompt.
        Whether to send the email if no video is recorded. If set to require a video, and none is added before the videoDueDate, the prompt is cancelled.

        :return: The send_without_video of this VideoEmailPrompt.
        :rtype: bool
        """
        return self._send_without_video

    @send_without_video.setter
    def send_without_video(self, send_without_video):
        """
        Sets the send_without_video of this VideoEmailPrompt.
        Whether to send the email if no video is recorded. If set to require a video, and none is added before the videoDueDate, the prompt is cancelled.

        :param send_without_video: The send_without_video of this VideoEmailPrompt.
        :type: bool
        """

        self._send_without_video = send_without_video

    @property
    def video_due_date(self):
        """
        Gets the video_due_date of this VideoEmailPrompt.
        When the video must be recorded by

        :return: The video_due_date of this VideoEmailPrompt.
        :rtype: datetime
        """
        return self._video_due_date

    @video_due_date.setter
    def video_due_date(self, video_due_date):
        """
        Sets the video_due_date of this VideoEmailPrompt.
        When the video must be recorded by

        :param video_due_date: The video_due_date of this VideoEmailPrompt.
        :type: datetime
        """

        self._video_due_date = video_due_date

    @property
    def scheduled_send_date(self):
        """
        Gets the scheduled_send_date of this VideoEmailPrompt.
        When the final email is scheduled to be sent

        :return: The scheduled_send_date of this VideoEmailPrompt.
        :rtype: datetime
        """
        return self._scheduled_send_date

    @scheduled_send_date.setter
    def scheduled_send_date(self, scheduled_send_date):
        """
        Sets the scheduled_send_date of this VideoEmailPrompt.
        When the final email is scheduled to be sent

        :param scheduled_send_date: The scheduled_send_date of this VideoEmailPrompt.
        :type: datetime
        """

        self._scheduled_send_date = scheduled_send_date

    @property
    def video_id(self):
        """
        Gets the video_id of this VideoEmailPrompt.
        The video that was added to the prompt. Read Only.

        :return: The video_id of this VideoEmailPrompt.
        :rtype: str
        """
        return self._video_id

    @property
    def email_id(self):
        """
        Gets the email_id of this VideoEmailPrompt.
        The email that was created by the prompt Read Only.

        :return: The email_id of this VideoEmailPrompt.
        :rtype: str
        """
        return self._email_id

    @property
    def job_id(self):
        """
        Gets the job_id of this VideoEmailPrompt.
        The job sent by the prompt Read Only.

        :return: The job_id of this VideoEmailPrompt.
        :rtype: str
        """
        return self._job_id

    @property
    def status(self):
        """
        Gets the status of this VideoEmailPrompt.
        The status of the prompt: created = 0, sent = 10, recorded = 20, job_created = 30, timed_out = 40, declined = 50 Read Only

        :return: The status of this VideoEmailPrompt.
        :rtype: int
        """
        return self._status

    @property
    def do_not_apply_template(self):
        """
        Gets the do_not_apply_template of this VideoEmailPrompt.
        Controls whether a user template is applied to the message as it is sent

        :return: The do_not_apply_template of this VideoEmailPrompt.
        :rtype: bool
        """
        return self._do_not_apply_template

    @do_not_apply_template.setter
    def do_not_apply_template(self, do_not_apply_template):
        """
        Sets the do_not_apply_template of this VideoEmailPrompt.
        Controls whether a user template is applied to the message as it is sent

        :param do_not_apply_template: The do_not_apply_template of this VideoEmailPrompt.
        :type: bool
        """

        self._do_not_apply_template = do_not_apply_template

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class OAuthClient(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, name=None, client_secret=None, grants_allowed=None, owning_user_id=None, redirect_uri=None):
        """
        OAuthClient - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'identifier': 'str',
            'name': 'str',
            'client_secret': 'str',
            'grants_allowed': 'str',
            'owning_user_id': 'str',
            'redirect_uri': 'str'
        }

        self.attribute_map = {
            'identifier': 'identifier',
            'name': 'name',
            'client_secret': 'clientSecret',
            'grants_allowed': 'grantsAllowed',
            'owning_user_id': 'owningUserId',
            'redirect_uri': 'redirectUri'
        }

        self._identifier = None
        self._name = name
        self._client_secret = client_secret
        self._grants_allowed = grants_allowed
        self._owning_user_id = owning_user_id
        self._redirect_uri = redirect_uri

    @property
    def identifier(self):
        """
        Gets the identifier of this OAuthClient.
        The id of the OAuth Client

        :return: The identifier of this OAuthClient.
        :rtype: str
        """
        return self._identifier

    @property
    def name(self):
        """
        Gets the name of this OAuthClient.
        The user-facing name of the client. Eg. MyCrm

        :return: The name of this OAuthClient.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OAuthClient.
        The user-facing name of the client. Eg. MyCrm

        :param name: The name of this OAuthClient.
        :type: str
        """

        self._name = name

    @property
    def client_secret(self):
        """
        Gets the client_secret of this OAuthClient.
        The secret supplied to the OAuth Application

        :return: The client_secret of this OAuthClient.
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """
        Sets the client_secret of this OAuthClient.
        The secret supplied to the OAuth Application

        :param client_secret: The client_secret of this OAuthClient.
        :type: str
        """

        self._client_secret = client_secret

    @property
    def grants_allowed(self):
        """
        Gets the grants_allowed of this OAuthClient.
        The grants allowed

        :return: The grants_allowed of this OAuthClient.
        :rtype: str
        """
        return self._grants_allowed

    @grants_allowed.setter
    def grants_allowed(self, grants_allowed):
        """
        Sets the grants_allowed of this OAuthClient.
        The grants allowed

        :param grants_allowed: The grants_allowed of this OAuthClient.
        :type: str
        """

        self._grants_allowed = grants_allowed

    @property
    def owning_user_id(self):
        """
        Gets the owning_user_id of this OAuthClient.
        The user who controls the OAuth App

        :return: The owning_user_id of this OAuthClient.
        :rtype: str
        """
        return self._owning_user_id

    @owning_user_id.setter
    def owning_user_id(self, owning_user_id):
        """
        Sets the owning_user_id of this OAuthClient.
        The user who controls the OAuth App

        :param owning_user_id: The owning_user_id of this OAuthClient.
        :type: str
        """

        self._owning_user_id = owning_user_id

    @property
    def redirect_uri(self):
        """
        Gets the redirect_uri of this OAuthClient.
        Where OAuth authorization sessions are returned to

        :return: The redirect_uri of this OAuthClient.
        :rtype: str
        """
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, redirect_uri):
        """
        Sets the redirect_uri of this OAuthClient.
        Where OAuth authorization sessions are returned to

        :param redirect_uri: The redirect_uri of this OAuthClient.
        :type: str
        """

        self._redirect_uri = redirect_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
